@@ -33,7 +33,7 @@ except ImportError as e:
 def run(run_id):
     """
     Creates a Run object for the specified run-id
-    
+
     Parameters
     ----------
     run_id: str
@@ -44,6 +44,7 @@ def run(run_id):
         Transcriptic representation of a Run object
     """
     from .jupyter import Run
+
     return Run(run_id)
 
 
@@ -61,6 +62,7 @@ def project(project_id):
         Transcriptic representation of a Project object
     """
     from .jupyter import Project
+
     return Project(project_id)
 
 
@@ -78,12 +80,13 @@ def container(container_id):
         Transcriptic representation of a Container object
     """
     from .jupyter import Container
+
     return Container(container_id)
 
 
 def preview(protocol):
     """
-    Creates a protocol preview object for the specified protocol 
+    Creates a protocol preview object for the specified protocol
 
     Parameters
     ----------
@@ -95,23 +98,24 @@ def preview(protocol):
         Transcriptic representation of a Protocol object
     """
     from .commands import ProtocolPreview
+
     return ProtocolPreview(protocol, api=api)
 
 
 def analyze(protocol, test_mode=False):
     """
-    Analyze a given protocol 
+    Analyze a given protocol
 
     Parameters
     ----------
     protocol: dict
         Autoprotocol JSON in dictionary format
     test_mode: boolean
-        whether protocol should be analyzed under test mode 
+        whether protocol should be analyzed under test mode
     Returns
     ------
     Analysis result: dict
-        Raw result of the analysis    
+        Raw result of the analysis
     """
     return api.analyze_run(protocol, test_mode)
 
@@ -119,7 +123,7 @@ def analyze(protocol, test_mode=False):
 def submit(protocol, project_id, title=None, test_mode=False):
     """
     Submit a given protocol
-    
+
     Parameters
     ----------
     protocol: dict
@@ -129,14 +133,15 @@ def submit(protocol, project_id, title=None, test_mode=False):
     title: str
         Name of Run
     test_mode: boolean
-        whether protocol should be submitted as a test run 
+        whether protocol should be submitted as a test run
     Returns
     ------
     Submission result: dict
-        Raw result of the submission    
+        Raw result of the submission
     """
-    return api.submit_run(protocol, project_id=project_id, title=title,
-                          test_mode=test_mode)
+    return api.submit_run(
+        protocol, project_id=project_id, title=title, test_mode=test_mode
+    )
 
 
 def dataset(data_id, key="*"):
@@ -149,20 +154,20 @@ def dataset(data_id, key="*"):
         Id of desired dataset, e.g. d123456789
     key
         Key of desired sub-fields of dataset
-    
+
     Returns
     ------
     Data: dict
-        Data in JSON form   
+        Data in JSON form
     """
     return api.dataset(data_id=data_id, key=key)
 
 
 def connect(transcriptic_path="~/.transcriptic"):
     """
-    Instantiates a Connection based on the specified path, and overwrites the 
+    Instantiates a Connection based on the specified path, and overwrites the
     existing `api` object with this Connection
-    
+
     Parameters
     ----------
     transcriptic_path:
@@ -172,5 +177,7 @@ def connect(transcriptic_path="~/.transcriptic"):
     try:
         api = Connection.from_file(transcriptic_path)
     except (OSError, IOError):
-        print("Unable to find .transcriptic file, please ensure the right path"
-              " is provided")
+        print(
+            "Unable to find .transcriptic file, please ensure the right path"
+            " is provided"
+        )
